pub enum ApiStability {
Experimental,
Beta,
Stable,
Deprecated,
}Expand description
API stability levels
Variants
Experimental
Experimental features that may change or be removed
Beta
Beta features that are mostly stable but may have minor changes
Stable
Stable features with backward compatibility guarantees
Deprecated
Deprecated features that will be removed in future versions